import { EngineComponent } from '../types/engine-component';
import { EngineEvents } from '../types/events';
import { GameRunner } from '../types/game-runner';
import { Instancable } from '../types/instancable';
import { EventEmitter } from '../utils/events';
import { WebGLRenderer } from './renderer';
export declare class Engine extends GameRunner {
    lastTick: number;
    running: boolean;
    events: EventEmitter<EngineEvents>;
    render: WebGLRenderer;
    element: HTMLElement;
    components: EngineComponent[];
    constructor();
    /**
     * Get global engine instance
     */
    static getInstance<E = Engine>(): E;
    mount(element: HTMLElement): void;
    loop(now: number): void;
    start(): void;
    stop(): void;
    /**
     * Update every component.
     */
    update(dt: number): void;
    /**
     * Use and initialize an engine component
     * @param Component Engine Component
     */
    use(Component: Instancable<EngineComponent>): EngineComponent;
    /**
     * Get an engine component.
     * @param component Component
     */
    getComponent<T extends EngineComponent>(component: Instancable<T>): T;
}
