import { PerspectiveCamera, Scene, Vector2, WebGLRenderer as ThreeWebGLRenderer, } from 'three';
export class WebGLRenderer {
    constructor(viewport, resolution = new Vector2(1080, 720), params) {
        this.viewport = viewport;
        this.resolution = resolution;
        this.params = params;
        this.renderer = new ThreeWebGLRenderer(this.params);
        this.camera = new PerspectiveCamera(75, this.resolution.x / this.resolution.y, 0.1, 10000);
        this.scene = new Scene();
        this.renderer.setSize(resolution.x, resolution.y);
        viewport.appendChild(this.renderer.domElement);
    }
    setSize(width, height) {
        this.resolution.set(width, height);
        this.camera.aspect = this.resolution.x / this.resolution.y;
        this.renderer.setSize(this.resolution.x, this.resolution.y);
        this.camera.updateProjectionMatrix();
    }
    render() {
        this.renderer.clear();
        this.renderer.render(this.scene, this.camera);
    }
    dispose() {
        this.renderer.dispose();
    }
}
