import 'reflect-metadata';
import { Property } from '../types/property';
/**
 * Register an exposed property. This is displayed in the editor and serialized to files.
 * @param editorPropertyDefinition Additional options
 */
export function ExposeProperty(editorPropertyDefinition) {
    return (target, propertyKey) => {
        let properties = Reflect.getOwnMetadata('properties', target);
        if (!properties) {
            Reflect.defineMetadata('properties', (properties = []), target);
        }
        properties.push(new Property({ ...editorPropertyDefinition, name: String(propertyKey) }));
    };
}
/**
 * Retract a property from an ancestor ExposedProperty list
 */
export function RetractProperty() {
    return (target, propertyKey) => {
        let excluded = Reflect.getOwnMetadata('excludedProperties', target);
        if (!excluded) {
            Reflect.defineMetadata('excludedProperties', (excluded = []), target);
        }
        excluded.push(String(propertyKey));
    };
}
