var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { GameObject3D } from '../types/game-object';
import { Color, Mesh, MeshPhongMaterial, } from 'three';
import { assetManager } from '../assets/manager';
import { AssetInfo } from '../types/asset';
import { ExposeProperty } from '../decorators/property';
export class PhysicalObject extends GameObject3D {
    get color() {
        return this.material?.color || this._color;
    }
    set color(color) {
        this._color = new Color(color);
        if (!this.material)
            return;
        this.material.color = this._color;
    }
    get transparency() {
        return this.material ? 1 - this.material.opacity : this._transparency;
    }
    set transparency(value) {
        this._transparency = value;
        if (!this.material)
            return;
        this.material.transparent = this._transparency != 0;
        this.material.opacity = 1 - this._transparency;
        this.material.needsUpdate = true;
    }
    get texture() {
        return this._texture;
    }
    set texture(path) {
        if (!path) {
            this._texture = undefined;
            if (!this.material)
                return;
            this.material.map = null;
            this.material.needsUpdate = true;
            return;
        }
        const asset = assetManager.getAssetByPath(path);
        if (!asset || !asset.texture) {
            console.error(`Asset ${path} does not exist or is not loaded`);
            return;
        }
        this._texture = path;
        if (!this.material)
            return;
        this.material.map = asset.texture;
        this.material.needsUpdate = true;
    }
    constructor() {
        super();
        this._color = new Color(0xffffff);
        this._transparency = 1;
        this.name = this.objectType;
    }
    getGeometry() {
        return this.geometry;
    }
    getMesh() {
        return this.mesh;
    }
    initializeMesh() {
        if (!this.geometry)
            return;
        if (this.mesh) {
            this.remove(this.mesh);
        }
        this.material = new MeshPhongMaterial();
        this.mesh = new Mesh(this.geometry, this.material);
        this.add(this.mesh);
    }
}
__decorate([
    ExposeProperty({ type: Color }),
    __metadata("design:type", Object),
    __metadata("design:paramtypes", [Object])
], PhysicalObject.prototype, "color", null);
__decorate([
    ExposeProperty({ type: Number }),
    __metadata("design:type", Number),
    __metadata("design:paramtypes", [Number])
], PhysicalObject.prototype, "transparency", null);
__decorate([
    ExposeProperty({ type: AssetInfo }),
    __metadata("design:type", Object),
    __metadata("design:paramtypes", [Object])
], PhysicalObject.prototype, "texture", null);
