import { Disposable } from './disposable';
import { WebGLRenderer } from '../core/renderer';
import { EventEmitter } from '../utils/events';
import { EngineEvents } from './events';
export declare abstract class EngineComponent implements Disposable {
    protected renderer: WebGLRenderer;
    protected events: EventEmitter<EngineEvents>;
    abstract name: string;
    constructor(renderer: WebGLRenderer, events: EventEmitter<EngineEvents>);
    /**
     * Initialize this component
     */
    abstract initialize(): void;
    /**
     * Update this component. Called on every frame.
     * @param delta Delta time
     */
    abstract update(delta: number): void;
    /**
     * Clean up the component
     */
    abstract dispose(): void;
}
